#!/usr/bin/env perl
use 5.012;
use Test::Most;
use Test::MockModule;
use lib '../lib';
use Data::Dump 'pp';

my @data = (
    {   mgi_accession_id   => 'MGI:1194490',
        ensembl_gene_ids   => [qw(ENSMUSG00000024456)],
        mgi2ensembl_output => <<'END_MGI_1194490',
MGI:1194490	ENSMUSG00000024456	OTTMUSG00000021095
END_MGI_1194490
    },
    {   mgi_accession_id => 'MGI:2684953',
        ensembl_gene_ids =>
            [qw(ENSMUSG00000067536 ENSMUSG00000073694 ENSMUSG00000079572)],
        mgi2ensembl_output => <<'END_MGI_2684953',
MGI:2684953	ENSMUSG00000067536	
MGI:2684953	ENSMUSG00000073694	
MGI:2684953	ENSMUSG00000079572	
END_MGI_2684953
    },
    {   mgi_accession_id   => 'MGI:2683305',
        ensembl_gene_ids   => [],
        mgi2ensembl_output => <<'END_MGI_2683305',
MGI:2683305		
END_MGI_2683305
    }
);

my $module = Test::MockModule->new('IPC::System::Simple');
$module->mock(
    capture => sub {
        my ( $executable_name, $mgi_accession_id ) = @_;
        my ($data) = grep $_->{mgi_accession_id} eq $mgi_accession_id, @data;
        return $data->{mgi2ensembl_output};
    }
);

use_ok( 'EnsemblUtils', 'mgi2ensembl' );

subtest "mocking external program's behaviour" => sub {
    for my $datum (@data) {
        is_deeply(
            [ mgi2ensembl( $datum->{mgi_accession_id} ) ],
            $datum->{ensembl_gene_ids},
            "got the expected EnsEMBL IDs for $datum->{mgi_accession_id}"
        );
    }
};

dies_ok { mgi2ensembl('NOT an MGI ID') }
  	"doesn't accept things other than mgi_accession_ids";

done_testing;
